aboutsummaryrefslogtreecommitdiffstats
path: root/include/scsi/libiscsi.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/scsi/libiscsi.h')
-rw-r--r--include/scsi/libiscsi.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/include/scsi/libiscsi.h b/include/scsi/libiscsi.h
index eea33f7b1544..3f631b08a1ab 100644
--- a/include/scsi/libiscsi.h
+++ b/include/scsi/libiscsi.h
@@ -228,8 +228,9 @@ struct iscsi_session {
char *password_in;
char *targetname;
char *initiatorname;
/* hw address being used for iscsi connection */
char *hwaddress;
+ char *netdev;
/* control data */
struct iscsi_transport *tt;
struct Scsi_Host *host;
@@ -228,8 +228,9 @@ struct iscsi_session {
char *targetname;
char *initiatorname;
- /* hw address being used for iscsi connection */
+ /* hw address or netdev iscsi connection is bound to */
char *hwaddress;